@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -63,6 +62,7 @@ def includeme(config):
     config.include('tailbone.views.people')
     config.include('tailbone.views.products')
     config.include('tailbone.views.progress')
+    config.include(u'tailbone.views.reportcodes')
     config.include('tailbone.views.roles')
     config.include('tailbone.views.stores')
     config.include('tailbone.views.subdepartments')
