@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -58,7 +57,7 @@ class CustomersGrid(SearchableAlchemyGridView):
     def filter_map(self):
         return self.make_filter_map(
             exact=['id'],
-            ilike=['name'],
+            name=self.filter_ilike_and_soundex(model.Customer.name),
             email=self.filter_ilike(model.CustomerEmailAddress.address),
             phone=self.filter_ilike(model.CustomerPhoneNumber.number))
 
